@@ -17,22 +17,12 @@
 
 from __future__ import annotations
 
-from collections.abc import Sequence
-from typing import TYPE_CHECKING, Callable
-
-from airflow.providers.snowflake.version_compat import AIRFLOW_V_3_0_PLUS
-
-if AIRFLOW_V_3_0_PLUS:
-    from airflow.sdk.bases.decorator import DecoratedOperator, task_decorator_factory
-else:
-    from airflow.decorators.base import DecoratedOperator, task_decorator_factory  # type: ignore[no-redef]
+from collections.abc import Callable, Sequence
 
+from airflow.providers.common.compat.sdk import DecoratedOperator, TaskDecorator, task_decorator_factory
 from airflow.providers.snowflake.operators.snowpark import SnowparkOperator
 from airflow.providers.snowflake.utils.snowpark import inject_session_into_op_kwargs
 
-if TYPE_CHECKING:
-    from airflow.sdk.bases.decorator import TaskDecorator
-
 
 class _SnowparkDecoratedOperator(DecoratedOperator, SnowparkOperator):
     """
